@@ -283,6 +283,17 @@ class Microservice(core.Construct):
             connection=self.tcp_connection_traffic_port,
             description="FAO HQ Clients",
         )
+        security_group.add_ingress_rule(
+            peer=self.azure_dev_a_as_peer(self._environments_parameters),
+            connection=self.tcp_connection_traffic_port,
+            description="AZURE DEV A",
+        )
+
+        security_group.add_ingress_rule(
+            peer=self.azure_dev_b_as_peer(self._environments_parameters),
+            connection=self.tcp_connection_traffic_port,
+            description="AZURE DEV B",
+        )
 
         return security_group
 
@@ -621,6 +632,33 @@ class Microservice(core.Construct):
         fao_networks = environments_parameters["networking"]
         return _ec2.Peer.ipv4(fao_networks["fao_hq_clients"])
 
+    @staticmethod
+    def azure_dev_a_as_peer(environments_parameters):
+        """Returns the AZURE DEV A network as Peer
+
+        Args:
+            environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
+
+        Returns:
+            aws_ec2.Peer: The AZURE DEV A network as Peer resource
+        """
+        fao_networks = environments_parameters["networking"]
+        return _ec2.Peer.ipv4(fao_networks["azure_dev_a"])
+
+    @staticmethod
+    def azure_dev_b_as_peer(environments_parameters):
+        """Returns the AZURE DEV B network as Peer
+
+        Args:
+            environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
+
+        Returns:
+            aws_ec2.Peer: The AZURE DEV B network as Peer resource
+        """
+        fao_networks = environments_parameters["networking"]
+        return _ec2.Peer.ipv4(fao_networks["azure_dev_b"])
+
+
     def asg_name(self):
         """Return the Auto Scaling Group name
 
@@ -856,6 +894,12 @@ class Microservice(core.Construct):
         self._fao_hq_clients_as_peer = self.fao_hq_clients_as_peer(
             self._environments_parameters
         )
+        self._azure_dev_a_as_peer = self.azure_dev_a_as_peer(
+            self._environments_parameters
+        )
+        self._azure_dev_b_as_peer = self.azure_dev_b_as_peer(
+            self._environments_parameters
+        )
         if has_upstream:
             upstream_security_group_as_peer = _ec2.SecurityGroup.from_security_group_id(
                 self, "upstream_security_group_"+main_component_name, upstream_security_group, mutable=True
@@ -940,6 +984,16 @@ class Microservice(core.Construct):
                     connection=_ec2.Port.tcp(80),
                     description="FAO HQ Clients",
                 )
+                self.alb_security_group.add_ingress_rule(
+                    peer=self._azure_dev_a_as_peer,
+                    connection=_ec2.Port.tcp(80),
+                    description="AZURE DEV A",
+                )
+                self.alb_security_group.add_ingress_rule(
+                    peer=self._azure_dev_b_as_peer,
+                    connection=_ec2.Port.tcp(80),
+                    description="AZURE DEV B",
+                )
             # Used when HTTPS is forced. These rules enable the redirect from HTTP -> HTTPS
             if is_public_has_no_upstream_and_is_https_and_no_cdn:
                 self.alb_security_group.add_ingress_rule(
@@ -1697,7 +1751,6 @@ class Microservice(core.Construct):
                     default_result=_asg.DefaultResult.CONTINUE,
                     heartbeat_timeout=core.Duration.seconds(60),
                     notification_metadata=json.dumps({"label": self._app_name + "-" + main_component_name}),
-                    role=asg_notifications_lifecycle_hook_role,
                 )
 
                 network_load_balancer_source_autoscaling_group.add_lifecycle_hook(
@@ -1707,5 +1760,4 @@ class Microservice(core.Construct):
                     default_result=_asg.DefaultResult.CONTINUE,
                     heartbeat_timeout=core.Duration.seconds(60),
                     notification_metadata=json.dumps({"label": self._app_name + "-" + main_component_name}),
-                    role=asg_notifications_lifecycle_hook_role,
                 )
\ No newline at end of file
